Welcome to the pySOT documentation! — pySOT documentation

# Welcome to the pySOT documentation!

This is the documentation for the Surrogate Optimization Toolbox (pySOT) for global deterministic optimization problems. pySOT is hosted on GitHub: https://github.com/dme65/pySOT.

The main purpose of the toolbox is for optimization of computationally expensive black-box objective functions with continuous and/or integer variables. All variables are assumed to have bound constraints in some form where none of the bounds are infinity. The tighter the bounds, the more efficient are the algorithms since it reduces the search region and increases the quality of the constructed surrogate. This toolbox may not be very efficient for problems with computationally cheap function evaluations. Surrogate models are intended to be used when function evaluations take from several minutes to several hours or more.

For easier understanding of the algorithms in this toolbox, it is recommended and helpful to read these papers. If you have any questions, or you encounter any bugs, please feel free to either submit a bug report on GitHub (recommended) or to contact me at the email address: dme65@cornell.edu. Keep an eye on the GitHub repository for updates and changes to both the toolbox and the documentation.

The toolbox is based on the following published papers: [1], [2], [3]

User Documentation

- Quickstart
  - Dependencies
  - Installation
- Surrogate optimization
- Options
  - Strategy
    - SRBFStrategy
    - DYCORStrategy
    - EIStrategy
    - LCBStrategy
  - Experimental design
    - LatinHypercube
    - SymmetricLatinHypercube
    - TwoFactorial
  - Surrogate model
    - RBFInterpolant
    - GPRegressor
    - MARSInterpolant
    - PolyRegressor
  - Optimization problem
- POAP
  - Controller
  - Strategy
  - Workers
  - Communication between POAP and pySOT
- Logging
- Source code
  - pySOT.auxiliary_problems module
  - pySOT.controller module
  - pySOT.experimental_design module
  - pySOT.optimization_problems module
  - pySOT.strategy module
  - pySOT.surrogate module
  - pySOT.utils module
- Changes
  - v.0.2.0, 2018-12-06
  - v.0.1.36, 2017-07-20
  - v.0.1.35, 2017-04-29
  - v.0.1.34, 2017-03-28
  - v.0.1.33, 2016-12-27
  - v.0.1.32, 2016-12-07
  - v.0.1.31, 2016-11-23
  - v.0.1.30, 2016-11-18
  - v0.1.29, 2016-10-20
  - v0.1.28, 2016-10-20
  - v0.1.27, 2016-10-18
  - v0.1.26, 2016-10-14
  - v0.1.25, 2016-09-14
  - v0.1.24, 2016-08-04
  - v0.1.23, 2016-07-28
  - v0.1.23, 2016-07-28
  - v0.1.22, 2016-06-27
  - v0.1.21, 2016-06-23
  - v0.1.20, 2016-06-18
  - v0.1.19, 2016-01-30
  - v0.1.18, 2016-01-24
  - v0.1.17, 2016-01-13
  - v0.1.16, 2016-01-06
  - v0.1.15, 2015-09-23
  - v0.1.14, 2015-09-22
  - v0.1.13, 2015-09-03
  - v0.1.12, 2015-07-23
  - v0.1.11, 2015-07-22
  - v0.1.10, 2015-07-14
  - v0.1.9, 2015-07-13
  - v0.1.8, 2015-07-01
  - v0.1.7, 2015-06-30
  - v0.1.6, 2015-06-28
  - v0.1.5, 2015-06-28
  - v0.1.4, 2015-06-26
  - v0.1.3, 2015-06-26
  - v0.1.2, 2015-06-24
  - v0.1.1, 2015-06-21
  - v0.1.0, 2015-06-03
- License
- Contributors

[1] | Rommel G Regis and Christine A Shoemaker. A stochastic radial basis function method for the global optimization of expensive functions. INFORMS Journal on Computing, 19(4): 497–509, 2007.

[2] | Rommel G Regis and Christine A Shoemaker. Parallel stochastic global optimization using radial basis functions. INFORMS Journal on Computing, 21(3):411–426, 2009.

[3] | Rommel G Regis and Christine A Shoemaker. Combining radial basis function surrogates and dynamic coordinate search in high-dimensional expensive black-box optimization. Engineering Optimization, 45(5): 529–555, 2013.